@@ -3,6 +3,7 @@ from widgets.streamlit.resource.dataframe import StDataFrame # noqa
 from widgets.streamlit.resource.dataframe import StDownloadDataFrame # noqa
 from widgets.streamlit.resource.expander import StExpander # noqa
 from widgets.streamlit.resource.columns import StColumns # noqa
+from widgets.streamlit.resource.selector import StSelector # noqa
 from widgets.streamlit.resource.value import StCheckbox # noqa
 from widgets.streamlit.resource.value import StFloat # noqa
 from widgets.streamlit.resource.value import StInteger # noqa
@@ -11,4 +12,5 @@ from widgets.streamlit.resource.value import StMultiSelect # noqa
 from widgets.streamlit.resource.value import StString # noqa
 from widgets.streamlit.resource.value import StSlider # noqa
 from widgets.streamlit.resource.markdown import StMarkdown # noqa
+from widgets.streamlit.resource.duplicator import StDuplicator # noqa
 from widgets.streamlit.widget.base import StreamlitWidget # noqa
