@@ -1,9 +1,8 @@
-import json
 from typing import Union
 import streamlit as st
 import pandas as pd
-from widgets.base.exceptions import ResourceConfigurationException
-from widgets.base.helpers import compress_string, decompress_string
+from widgets.base.helpers import parse_dataframe_string
+from widgets.base.helpers import encode_dataframe_string
 from widgets.streamlit.resource.value import StValue
 
 
@@ -46,39 +45,14 @@ class StDataFrame(StValue):
                             Default is "visible"
             sidebar (bool): Set up UI in the sidebar vs. the main container
             show_uploader:  Show / hide the uploader element
-            show_downloader: Show / hide the downloader element
 
         Returns:
             StResource:     The instantiated resource object.
         """
 
-        # If the value is a string, try to decompress it
-        if isinstance(value, str):
-            try:
-                value = pd.DataFrame(
-                    json.loads(
-                        decompress_string(value)
-                    )
-                )
-            except Exception as e:
-                msg = f"value could not be decompressed from string ({str(e)})"
-                raise ResourceConfigurationException(msg)
-        # If the value is a dict, convert it
-        elif isinstance(value, dict):
-            try:
-                value = pd.DataFrame(value)
-            except Exception as e:
-                msg = f"value could not be converted to DataFrame ({str(e)})"
-                raise ResourceConfigurationException(msg)
-        # If the value is a DataFrame, keep it
-        elif isinstance(value, pd.DataFrame):
-            pass
-        # If the value is None, make an empty DataFrame
-        elif value is None:
-            value = pd.DataFrame()
-        else:
-            msg = f"value must be None, dict, or DataFrame, not {type(value)}"
-            raise ResourceConfigurationException(msg)
+        # Parse the provided value, converting from a gzip-compressed
+        # string if necessary
+        value = parse_dataframe_string(value)
 
         # Set up the resource attributes
         super().__init__(
@@ -137,23 +111,7 @@ class StDataFrame(StValue):
         if isinstance(val, str):
             return f'"{val}"'
         elif isinstance(val, pd.DataFrame):
-            # Convert to dict
-            val_dict = val.to_dict(orient="list")
-            # Convert to string
-            val_str = json.dumps(val_dict)
-            # Compress the string
-            val_comp = compress_string(val_str)
-
-            # If the compressed string is shorter
-            if len(val_comp) < len(val_str):
-
-                # Return the compressed version,
-                # embedded in quotes
-                return f'"{val_comp}"'
-            # If the compressed string is longer
-            else:
-                # Return the JSON serialization
-                return val_str
+            return encode_dataframe_string(val)
 
         else:
             return val
